type HighlightOptions = {
    caseSensitive?: boolean;
    /**
     * Selector for the container element.
     */
    containerClass?: string;
    excludeSelector?: string;
    containerSelector?: string;
    /**
     * The configuration for the highlight element.
     */
    tagName?: string;
    className?: string;
    customStyles?: Partial<CSSStyleDeclaration>;
    /**
     * If deepSearch = true, the highlight will also search through the highlighted elements.
     */
    deepSearch?: boolean;
    /**
     * The attribute name to store the highlighter instance id.
     * @default 'data-highlighter-instance'
     */
    instanceAttributeName?: string;
};
export declare class Highlighter {
    private static highlighterIdCounter;
    private static sharedStyleElement;
    private static ensureSharedStyleElementInitialized;
    private options;
    private instanceId;
    constructor(options?: HighlightOptions);
    highlight(pattern: string | string[] | RegExp): void;
    removeHighlights(): void;
    private applyCustomStyles;
    private buildMergedRegex;
    private searchAndHighlight;
    /**
     * When deepSearch = true, enable the new "merge text + Range" highlighting method.
     * Core idea:
     * 1. Collect all visible text within the element and record their distribution (offset) in the DOM.
     * 2. Perform regex search on the merged string to get all match start/end positions.
     * 3. Convert each match into a DOM Range and insert a new highlight tag by wrapping.
     */
    private searchAndHighlightDeep;
    /**
     * Given global start/end, find the corresponding Text node range and wrap it with a Range.
     */
    private wrapRangeDeep;
    private wrapNode;
    private wrapText;
}
export {};
